package com.example.fieldagent.ui.damagelist

import android.os.Bundle
import androidx.fragment.app.Fragment
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.viewModels
import androidx.lifecycle.Observer
import androidx.navigation.fragment.findNavController
import com.consultantapp.data.network.responseUtil.Status
import com.example.fieldagent.R
import com.example.fieldagent.data.network.ApisRespHandler
import com.example.fieldagent.databinding.FragmentDamageListBinding
import com.example.fieldagent.ui.damagelist.adapter.DamageListAdapter
import com.example.fieldagent.utils.PrefsManager
import com.example.fieldagent.utils.dialogs.ProgressDialog
import com.example.fieldagent.utils.showConfirmDialog
import dagger.hilt.android.AndroidEntryPoint
import java.util.HashMap
import javax.inject.Inject


@AndroidEntryPoint
class DamageListFragment : Fragment() {

    private var _binding: FragmentDamageListBinding? = null

    private val binding get() = _binding!!

    private  val viewModel: DamageListFragmentVM by viewModels()

    @Inject
    lateinit var prefsManager: PrefsManager

    private lateinit var progressDialog: ProgressDialog

    private lateinit var adapter: DamageListAdapter

    private var inspectionId=""
    private var clickDeletePos=-1

    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentDamageListBinding.inflate(inflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)


        initialize()
        listener()
        bindObservers()

    }

   private fun initialize(){

       progressDialog = ProgressDialog(requireActivity())
       adapter = DamageListAdapter()
       binding.rvDamageList.adapter = adapter

       inspectionId = arguments?.getString("id").toString()
       val name = arguments?.getString("name").toString()

       // Use the data
       name.let {
          binding.txtTitle.text=name
       }
       val hashMap = HashMap<String, String>()
       hashMap["id"] = inspectionId
       viewModel.getDamagesList(hashMap)
    }


   private fun bindObservers(){
       viewModel.damages.observe(requireActivity(), Observer {
           it ?: return@Observer
           when (it.status) {
               Status.SUCCESS -> {

                   progressDialog.setLoading(false)

                   val tempList = it.data?.data?.inspections ?: emptyList()

                   tempList[0].damages?.let { it1 ->
                       adapter.submitList(it1)
                       binding.damageCount.text=String.format("%02d", it1.size)
                   }



               }
               Status.ERROR -> {
                   progressDialog.setLoading(false)
                   ApisRespHandler.handleError(it.error, requireActivity())
               }
               Status.LOADING -> {
                   progressDialog.setLoading(true)
               }
           }
       })
    }

    private fun listener(){

        binding.llBtn.setOnClickListener{


            val bundle = Bundle().apply {
                putString("id", inspectionId)
            }
            findNavController().navigate(R.id.damageDeatilsFragment, bundle)
        }
        binding.ivLeft.setOnClickListener {

            findNavController().popBackStack()
        }

    }


    fun clickItem(pos: Int) {
       // findNavController().navigate(R.id.damageListFragment, bundle)

    }
    fun clickDeleteItem(pos: Int,) {

      /*  if (pos < 0 || pos >= items.size) {
            return
        }
        clickDeletePos=pos


        requireContext().showConfirmDialog(
            title = getString(R.string.are_you_sure_you_want_to_delete)
        ) {
            viewModel.deleteInspection(items[pos].id.toString())
        }
*/
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}